// $Id: PacketHandler.java,v 1.1 2001/06/01 06:32:50 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.capture;


/**
 * Classes that implement this interface are capable of handling
 * raw packet data.
 * <p>
 * What the implementor does with the data isn't specified.
 * The handler could consume the data, print it, broadcast it, whatever.
 * <p>
 * Since jpcap.capture has to do with capturing packet data, all of the 
 * implementors in this package handle packet data by receiving it 
 * (from the underlying native methods for packet capture) and then 
 * dispatching it (to clients interested in the data.)
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.1 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/06/01 06:32:50 $
 */
public interface PacketHandler
{
  /**
   * Handle an arriving packet.
   * 
   * @param length the length of the packet off of the wire.
   * @param caplen the number of bytes actually captured.
   * @param seconds the seconds component of the timestamp.
   * @param useconds the microseconds component of the timestamp.
   * @param data the contents of the captured packet.
   */
  void handlePacket(int length, int caplen, int seconds, int useconds, 
                    byte [] data);
}
